// Example601D
#include "SparkFunBME280.h"
#include "LiquidCrystal_I2C.h"

// Temperature, Humidity, Pressure sensor
BME280 bme280;
float t, h; // variables for temperature, humidity

// LCD 1602
LiquidCrystal_I2C lcd(0x27, 16, 2);

void setup() {
  // BME280 setting
  bme280.settings.commInterface   = I2C_MODE;
  bme280.settings.I2CAddress      = 0x76;
  bme280.settings.runMode         = 3;
  bme280.settings.tStandby        = 0;
  bme280.settings.filter          = 0;
  bme280.settings.tempOverSample  = 1;
  bme280.settings.pressOverSample = 1;
  bme280.settings.humidOverSample = 1;
  delay(10);
  bme280.begin();

  // Serial communication starts
  Serial.begin(9600);

  // LCD starts
  lcd.init();
  lcd.backlight();
  lcd.clear();
}

long s_time = 0, e_time = 0;

void loop() {
  s_time = millis();
  bme280Read();
  bme280SerialPrint();
  bme280LcdPrint();
  e_time = millis();
  Serial.println(e_time - s_time);
  delay(1000);
}

void bme280Read() {
  t = bme280.readTempC();
  h = bme280.readFloatHumidity();
}

void bme280SerialPrint() {
  // temperature
  Serial.print(t, 1); // 温度，小数第一位まで
  Serial.write(0xDF);
  Serial.println("C ");
  // humidity
  Serial.print(h, 1); // 湿度，小数第一位まで
  Serial.println("%");
}

void bme280LcdPrint() {
  // Temperature
  lcd.setCursor(0, 0);
  lcd.print(t, 1); // 温度，小数第一位まで
  lcd.write(0xDF);
  lcd.print("C ");
  // Humidity
  lcd.setCursor(0, 1); // 湿度，小数第一位まで
  lcd.print(h, 1);
  lcd.print("%");
}

