// Example601E
#include "SparkFunBME280.h"
#include "LiquidCrystal_I2C.h"

// Temperature, Humidity, Pressure sensor
BME280 bme280;
float t, h; // variables for temperature, humidity

// LCD 1602
LiquidCrystal_I2C lcd(0x27, 16, 2);

void setup() {
  // BME280 setting
  bme280.settings.commInterface   = I2C_MODE;
  bme280.settings.I2CAddress      = 0x76;
  bme280.settings.runMode         = 3;
  bme280.settings.tStandby        = 0;
  bme280.settings.filter          = 0;
  bme280.settings.tempOverSample  = 1;
  bme280.settings.pressOverSample = 1;
  bme280.settings.humidOverSample = 1;
  delay(10);
  bme280.begin();

  // Serial communication starts
  Serial.begin(9600);

  // LCD starts
  lcd.init();
  lcd.backlight();
  lcd.clear();
}

long c_time = 0, p_time = 0;
long s_time = 0, e_time = 0;

void loop() {
  c_time = millis();
  if (c_time - p_time > 1000) {
    p_time = c_time;

    // 関数の実行時間計測
    s_time = millis();
    bme280Read(); // 2ms
//    bme280SerialPrint(); // 2ms-3ms
    bme280LcdPrint(); // 20ms-21ms
    e_time = millis();

    Serial.print(e_time - s_time);
  }
}

void bme280Read() {
  t = bme280.readTempC();
  h = bme280.readFloatHumidity();
}

void bme280SerialPrint() {
  // temperature
  Serial.print(t, 1); // 温度，小数第一位まで
  Serial.write(0xDF);
  Serial.println("C ");
  // humidity
  Serial.print(h, 1); // 湿度，小数第一位まで
  Serial.println("%");
}

void bme280LcdPrint() {
  // Temperature
  lcd.setCursor(0, 0);
  lcd.print(t, 1); // 温度，小数第一位まで
  lcd.write(0xDF);
  lcd.print("C ");
  // Humidity
  lcd.setCursor(0, 1); // 湿度，小数第一位まで
  lcd.print(h, 1);
  lcd.print("%");
}

