// Example603B
#include "FastLED.h"
#include "SparkFunBME280.h"
#include "LiquidCrystal_I2C.h"

// Temperature, Humidity, Pressure sensor
BME280 bme280;
float t, h; // variables for temperature, humidity

// LCD 1602
LiquidCrystal_I2C lcd(0x27, 16, 2);

// Full color LED
#define DATA_PIN 12
#define NUM_LEDS  1
CRGB leds[NUM_LEDS];

void setup() {
  // BME280 setting
  bme280.settings.commInterface   = I2C_MODE;
  bme280.settings.I2CAddress      = 0x76;
  bme280.settings.runMode         = 3;
  bme280.settings.tStandby        = 0;
  bme280.settings.filter          = 0;
  bme280.settings.tempOverSample  = 1;
  bme280.settings.pressOverSample = 1;
  bme280.settings.humidOverSample = 1;
  delay(10);
  bme280.begin();

  // Serial communication starts
  Serial.begin(9600);

  // LCD starts
  lcd.init();
  lcd.backlight();
  lcd.clear();

  // Full color LED starts
  FastLED.addLeds<WS2811, DATA_PIN, RGB>(leds, NUM_LEDS);
  FastLED.setBrightness(20);
  leds[0] = CRGB(0, 0, 0);
  FastLED.show();
}

long c_time = 0, p_time = 0; // current time, past time

void loop() {
  c_time = millis();
  if (c_time - p_time > 1000) {
    p_time = c_time;
    bme280Read();
    bme280SerialPrint();
    bme280LcdPrint();
    float di = bme280DI();
    //    di = 60; // for test
    Serial.println(di);
    int hue = map((int)di, , , , 0); // 不快指数 から を色相にマッピング
    leds[0] = CHSV(hue, 255, 255);
    FastLED.show();
  }
}

void bme280Read() {
  t = bme280.readTempC();
  h = bme280.readFloatHumidity();
}

void bme280SerialPrint() {
  // temperature
  Serial.print(t, 1); // 温度，小数第一位まで
  Serial.write(0xDF);
  Serial.println("C ");
  // humidity
  Serial.print(h, 1); // 湿度，小数第一位まで
  Serial.println("%");
}

void bme280LcdPrint() {
  // Temperature
  lcd.setCursor(0, 0);
  lcd.print(t, 1); // 温度，小数第一位まで
  lcd.write(0xDF);
  lcd.print("C ");
  // Humidity
  lcd.setCursor(0, 1); // 湿度，小数第一位まで
  lcd.print(h, 1);
  lcd.print("%");
}

float bme280HI() {
  // Adapted from equation at: https://github.com/adafruit/DHT-sensor-library/issues/9 and
  // Wikipedia: http://en.wikipedia.org/wiki/Heat_index
  float hi = -8.784695 +
             1.61139411 * t + 2.338549   * h +
             -0.14611605 * t * h +
             -0.01230809 * pow(t, 2) +
             -0.01642482 * pow(h, 2) +
             0.00221173 * pow(t, 2) * h +
             0.00072546 * t * pow(h, 2) +
             -0.00000358 * pow(t, 2) * pow(h, 2);

  return hi;
}


float bme280DI() {
  float di = 0.81*t+0.01*h*(0.99*t-14.3)+46.3
  return di;
}

